#
# spec file for package hidviz
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hidviz
Version:        0.2.1
Release:        1.3
Summary:        A tool for in-depth analysis of USB HID devices communication
License:        GPL-3.0-or-later
URL:            https://hidviz.org/
Source0:        https://github.com/hidviz/hidviz/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE hidviz-libexec_path.patch
Patch0:         hidviz-libexec_path.patch
BuildRequires:  ImageMagick
BuildRequires:  asio-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(protobuf)

%description
Hidviz is a GUI application for in-depth analysis of USB HID class devices.
The 2 main usecases of this application are reverse-engineering existing
devices and developing new USB HID devices.

%prep
%autosetup -p1
sed -i 's|__LIBEXECDIR__|%{_libexecdir}|' libhidx/libhidx/src/Connector.cc

%build
%cmake \
    -DCMAKE_INSTALL_LIBEXECDIR=%{_libexecdir} \
    -DBUILD_SHARED_LIBS:BOOL=OFF
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_libexecdir}/libhidx_server_daemon

%changelog
* Thu Apr 17 2025 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.2.1
  Build fixes:
  * fixed build with gcc-15
  * fixed build with cmake 4.0 and newer
* Thu Mar 16 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.2
  * fixed build with cmake 3.17
  * imported libhidx directly into the sources (fixes a lot of
    compilation issues)
  * updated to QT6
  * added a new icon
- Drop hidviz-moc_policy.patch and hidviz-gcc11.patch (no longer
  necessary)
* Fri Jun  4 2021 Luigi Baldoni <aloisio@gmx.com>
- Ad hidviz-gcc11.patch and fix build in Factory
* Sun May  3 2020 Luigi Baldoni <aloisio@gmx.com>
- Add hidviz-moc_policy.patch to fix build problem
* Thu Dec  5 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Use convert -strip to drop png timestamps to make
  package build reproducible (boo#1047218)
* Mon Dec  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v0.1.5)
